==> yos.core-1.0.0-sources.jar: common/data/FieldMeta.java <==
package common.data;

public class FieldMeta {
    private Class fieldtype;
    private String table_name;
    private String table_alias;
    private String column_name;
    private String column_lable;
    private int precision;
    private int scale;

    /**
     * 获取字段的类型
     *
     * @return
     */
    public Class getFieldtype() {
        return fieldtype;
    }

    public void setFieldtype(Class fieldtype) {
        this.fieldtype = fieldtype;
    }

    public String getColumn_lable() {
        return column_lable == null ? "" : column_lable;
    }

    public void setColumn_lable(String column_lable) {
        this.column_lable = column_lable;
    }

    public String getTable_alias() {
        return table_alias == null ? "" : table_alias;
    }

    public void setTable_alias(String table_alias) {
        this.table_alias = table_alias;
    }

    /**
     * 获取字段所属表的名称
     *
     * @return
     */
    public String getTable_name() {
        return table_name == null ? "" : table_name;
    }

    public void setTable_name(String table_name) {
        this.table_name = table_name;
    }

    /**
     * 获取字段所属表的字段名称
     *
     * @return
     */
    public String getColumn_name() {
        return column_name;
    }

    public void setColumn_name(String column_name) {
        this.column_name = column_name;
    }

    /**
     * 获取字段的长度
     *
     * @return
     */
    public int getPrecision() {
        return precision;
    }

    public void setPrecision(int precision) {
        this.precision = precision;
    }

    /**
     * 获取字段的精度
     *
     * @return
     */
    public int getScale() {
        return scale;
    }

    public void setScale(int scale) {
        this.scale = scale;
    }
}

==> yos.core-2.2.1-sources.jar: common/data/FieldMeta.java <==
package common.data;

public class FieldMeta {
    private Class fieldtype;
    private String table_name;
    private String table_alias;
    private String column_name;
    private String column_label;
    private int precision;
    private int scale;

    /**
     * 获取字段的类型
     *
     * @return
     */
    public Class getFieldtype() {
        return fieldtype;
    }

    public void setFieldtype(Class fieldtype) {
        this.fieldtype = fieldtype;
    }

    public String getColumn_label() {
        return column_label == null ? "" : column_label;
    }

    public void setColumn_label(String column_label) {
        this.column_label = column_label;
    }

    public String getTable_alias() {
        return table_alias == null ? "" : table_alias;
    }

    public void setTable_alias(String table_alias) {
        this.table_alias = table_alias;
    }

    /**
     * 获取字段所属表的名称
     *
     * @return
     */
    public String getTable_name() {
        return table_name == null ? "" : table_name;
    }

    public void setTable_name(String table_name) {
        this.table_name = table_name;
    }

    /**
     * 获取字段所属表的字段名称
     *
     * @return
     */
    public String getColumn_name() {
        return column_name;
    }

    public void setColumn_name(String column_name) {
        this.column_name = column_name;
    }

    /**
     * 获取字段的长度
     *
     * @return
     */
    public int getPrecision() {
        return precision;
    }

    public void setPrecision(int precision) {
        this.precision = precision;
    }

    /**
     * 获取字段的精度
     *
     * @return
     */
    public int getScale() {
        return scale;
    }

    public void setScale(int scale) {
        this.scale = scale;
    }
}
